@@ -5,10 +5,10 @@ context("Test the generic list")
 source(paste0("", "testUtils.R"))
 
 test_that("GetByIndex method works well", {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   
   depot <- model@compartments %>% getByIndex(1)
   expect_equal(depot@name, "DEPOT")
   
   expect_error(model@compartments %>% getByIndex(5), regexp="Can't find element at index 5")
-})
\ No newline at end of file
+})
